@@ -138,14 +138,14 @@ void CalendarIndexer::indexEventItem(const Akonadi::Item &item, const KCalCore::
 {
     Akonadi::Search::XapianDocument doc;
 
-    doc.indexText(event->organizer()->email(), QStringLiteral("O"));
+    doc.indexText(event->organizer().email(), QStringLiteral("O"));
     doc.indexText(event->summary(), QStringLiteral("S"));
     doc.indexText(event->location(), QStringLiteral("L"));
     KCalCore::Attendee::List attendees = event->attendees();
     KCalCore::Attendee::List::ConstIterator it;
     KCalCore::Attendee::List::ConstIterator end(attendees.constEnd());
     for (it = attendees.constBegin(); it != end; ++it) {
-        doc.addBoolTerm((*it)->email() + QString::number((*it)->status()), QStringLiteral("PS"));
+        doc.addBoolTerm((*it).email() + QString::number((*it).status()), QStringLiteral("PS"));
     }
 
     // Parent collection
