@@ -16,7 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -78,7 +78,8 @@ Term recursiveEmailTermMapping(const Akonadi::SearchTerm &term)
 {
     if (!term.subTerms().isEmpty()) {
         Term t(mapRelation(term.relation()));
-        Q_FOREACH (const Akonadi::SearchTerm &subterm, term.subTerms()) {
+        const auto subTermsResult = term.subTerms();
+        for (const Akonadi::SearchTerm &subterm : subTermsResult) {
             const Term newTerm = recursiveEmailTermMapping(subterm);
             if (newTerm.isValid()) {
                 t.addSubTerm(newTerm);
